searchData={"items":[{"type":"module","title":"Enviable","doc":"- code :: https://github.com/halostatue/enviable\n- issues :: https://github.com/halostatue/enviable/issues\n\nEnviable is a small collection of functions and delegates that makes working\nwith operating system environment functions a little easier. It exists for two\nreasons:\n\n- Functions like `Enviable.put_env_new/2` do not exist in `System` and are\n  easier to read than either `System.put_env/2` or `System.put_env/1` in\n  conjunction with `System.get_env/2`.\n\n- Modules in dependencies can reliably be used or `include`d in configuration\n  files in ways that in-source functions cannot be.\n\nDelegates are defined for `System.delete_env/1`, `System.fetch_env/1`,\n`System.fetch_env!/1`, `System.get_env/0`, `System.get_env/2`,\n`System.put_env/1`, and `System.put_env/2`.","ref":"Enviable.html"},{"type":"module","title":"Usage - Enviable","doc":"This will typically be used in `config/*.exs` files alongside [Dotenvy][dotenvy]\nor similar configuration tools based around environment variables.\n\n```elixir\n# config/runtime.exs\ninclude Config\ninclude Enviable\n\nclient = fetch_env!(\"CLIENT\")\nDotenvy.source([\".env\", \".env.#{client}\", System.get_env()])\n\nconfig :my_app,\n  key: fetch_env!(\"SECRET_KEY\"),\n  port: fetch_env_integer!(\"PORT\"),\n  ssl: fetch_env_boolean!(\"SSL_ENABLED\")\n```\n\n```elixir\n# config/dev.exs\ninclude Config\nEnviable.put_env_new(\"SSL_ENABLED\", false)\n```","ref":"Enviable.html#module-usage"},{"type":"module","title":"Installation - Enviable","doc":"Enviable can be installed by adding `enviable` to your list of dependencies in\n`mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:enviable, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation is found on [HexDocs][docs].","ref":"Enviable.html#module-installation"},{"type":"module","title":"Semantic Versioning - Enviable","doc":"`Enviable` uses a [Semantic Versioning][semver] scheme with one significant\nchange:\n\n- When PATCH is zero (`0`), it will be omitted from version references.\n\n[docs]: https://hexdocs.pm/enviable\n[semver]: http://semver.org/\n[dotenvy]: https://hexdocs.pm/dotenvy/readme.html","ref":"Enviable.html#module-semantic-versioning"},{"type":"function","title":"Enviable.delete_env/1","doc":"Deletes an environment variable, removing `varname` from the environment.","ref":"Enviable.html#delete_env/1"},{"type":"function","title":"Enviable.fetch_env/1","doc":"Returns the value of the given environment variable or :error if not found.\n\nIf the environment variable varname is set, then {:ok, value} is returned where value is\na string. If varname is not set, :error is returned.","ref":"Enviable.html#fetch_env/1"},{"type":"function","title":"Examples - Enviable.fetch_env/1","doc":"iex> Enviable.fetch_env(\"PORT\")\n    :error\n\n    iex> Enviable.put_env(\"PORT\", \"4000\")\n    iex> Enviable.fetch_env(\"PORT\")\n    {:ok, \"4000\"}","ref":"Enviable.html#fetch_env/1-examples"},{"type":"function","title":"Enviable.fetch_env!/1","doc":"Returns the value of the given environment variable or raises if not found.\n\nSame as `get_env/1` but raises instead of returning `nil` when the variable is\nnot set.","ref":"Enviable.html#fetch_env!/1"},{"type":"function","title":"Examples - Enviable.fetch_env!/1","doc":"iex> Enviable.fetch_env!(\"PORT\")\n    ** (System.EnvError) could not fetch environment variable \"PORT\" because it is not set\n\n    iex> Enviable.put_env(\"PORT\", \"4000\")\n    iex> Enviable.fetch_env!(\"PORT\")\n    \"4000\"","ref":"Enviable.html#fetch_env!/1-examples"},{"type":"function","title":"Enviable.fetch_env_boolean/2","doc":"Returns the value of an environment variable as `{:ok, t:boolean/0}` value or `:error`\nif the variable is unset.\n\nBy default, the values `\"1\"` and `\"true\"` are considered `true` values. Any other value\nwill be considered `false`.\n\nThis function accepts the following conversion options:\n\n- `truthy`: a list of string values to be compared for truth values. Mutually exclusive\n  with `falsy`.\n- `falsy`: a list of string values to be compared for false values. Mutually exclusive\n  with `truthy`.\n- `downcase`: either `false` (the default), `true`, or the mode parameter for\n  `String.downcase/2` (`:default`, `:ascii`, `:greek`, or `:turkic`).","ref":"Enviable.html#fetch_env_boolean/2"},{"type":"function","title":"Examples - Enviable.fetch_env_boolean/2","doc":"iex> Enviable.fetch_env_boolean(\"COLOR\")\n    :error\n\n    iex> Enviable.put_env(\"COLOR\", \"1\")\n    iex> Enviable.fetch_env_boolean(\"COLOR\")\n    {:ok, true}\n\n    iex> Enviable.put_env(\"COLOR\", \"something\")\n    iex> Enviable.fetch_env_boolean(\"COLOR\")\n    {:ok, false}\n\n    iex> Enviable.put_env(\"COLOR\", \"oui\")\n    iex> Enviable.fetch_env_boolean(\"COLOR\", truthy: [\"oui\"])\n    {:ok, true}\n\n    iex> Enviable.put_env(\"COLOR\", \"OUI\")\n    iex> Enviable.fetch_env_boolean(\"COLOR\", truthy: [\"oui\"])\n    {:ok, false}\n    iex> Enviable.fetch_env_boolean(\"COLOR\", truthy: [\"oui\"], downcase: true)\n    {:ok, true}\n\n    iex> Enviable.put_env(\"COLOR\", \"NON\")\n    iex> Enviable.fetch_env_boolean(\"COLOR\", falsy: [\"non\"])\n    {:ok, true}\n    iex> Enviable.fetch_env_boolean(\"COLOR\", falsy: [\"non\"], downcase: true)\n    {:ok, false}\n\n    # Any `default` value is ignored.\n    iex> Enviable.fetch_env_boolean(\"COLOR\", default: nil)\n    :error\n\n    iex> Enviable.fetch_env_boolean(\"COLOR\", downcase: nil)\n    ** (ArgumentError) cannot execute Enviable.fetch_env_boolean/2 with invalid `downcase` value\n\n    iex> Enviable.fetch_env_boolean(\"COLOR\", truthy: [\"oui\"], falsy: [\"non\"])\n    ** (ArgumentError) cannot execute Enviable.fetch_env_boolean/2 with both `truthy` and `falsy` options","ref":"Enviable.html#fetch_env_boolean/2-examples"},{"type":"function","title":"Enviable.fetch_env_boolean!/2","doc":"Returns the value of an environment variable as a `t:boolean/0` value or raises an\nexception if the variable is unset.\n\nBy default, the values `\"1\"` and `\"true\"` are considered `true` values. Any other value\nwill be considered `false`.\n\nThis function accepts the following conversion options:\n\n- `truthy`: a list of string values to be compared for truth values. Mutually exclusive\n  with `falsy`.\n- `falsy`: a list of string values to be compared for false values. Mutually exclusive\n  with `truthy`.\n- `downcase`: either `false` (the default), `true`, or the mode parameter for\n  `String.downcase/2` (`:default`, `:ascii`, `:greek`, or `:turkic`).","ref":"Enviable.html#fetch_env_boolean!/2"},{"type":"function","title":"Examples - Enviable.fetch_env_boolean!/2","doc":"iex> Enviable.fetch_env_boolean!(\"COLOR\")\n    ** (System.EnvError) could not fetch environment variable \"COLOR\" because it is not set\n\n    iex> Enviable.put_env(\"COLOR\", \"1\")\n    iex> Enviable.fetch_env_boolean!(\"COLOR\")\n    true\n\n    iex> Enviable.put_env(\"COLOR\", \"something\")\n    iex> Enviable.fetch_env_boolean!(\"COLOR\")\n    false\n\n    iex> Enviable.put_env(\"COLOR\", \"oui\")\n    iex> Enviable.fetch_env_boolean!(\"COLOR\", truthy: [\"oui\"])\n    true\n\n    iex> Enviable.put_env(\"COLOR\", \"OUI\")\n    iex> Enviable.fetch_env_boolean!(\"COLOR\", truthy: [\"oui\"])\n    false\n    iex> Enviable.fetch_env_boolean!(\"COLOR\", truthy: [\"oui\"], downcase: true)\n    true\n\n    iex> Enviable.put_env(\"COLOR\", \"NON\")\n    iex> Enviable.fetch_env_boolean!(\"COLOR\", falsy: [\"non\"])\n    true\n    iex> Enviable.fetch_env_boolean!(\"COLOR\", falsy: [\"non\"], downcase: true)\n    false\n\n    # Any `default` value is ignored.\n    iex> Enviable.fetch_env_boolean!(\"COLOR\", default: nil)\n    ** (System.EnvError) could not fetch environment variable \"COLOR\" because it is not set\n\n    iex> Enviable.fetch_env_boolean!(\"COLOR\", downcase: nil)\n    ** (ArgumentError) cannot execute Enviable.fetch_env_boolean!/2 with invalid `downcase` value\n\n    iex> Enviable.fetch_env_boolean!(\"COLOR\", truthy: [\"oui\"], falsy: [\"non\"])\n    ** (ArgumentError) cannot execute Enviable.fetch_env_boolean!/2 with both `truthy` and `falsy` options","ref":"Enviable.html#fetch_env_boolean!/2-examples"},{"type":"function","title":"Enviable.fetch_env_integer/2","doc":"Returns the value of an environment variable as `{:ok, t:integer/0}` or `:error` if the\nvariable is unset.\n\nThis function accepts the following conversion option:\n\n- `base`: The base (`2..36`) for integer conversion. Defaults to `10` like\n  `String.to_integer/2`.\n\nFailure to parse the value of the environment variable will result in an exception.","ref":"Enviable.html#fetch_env_integer/2"},{"type":"function","title":"Examples - Enviable.fetch_env_integer/2","doc":"iex> Enviable.fetch_env_integer(\"COLOR\")\n    :error\n\n    iex> Enviable.put_env(\"COLOR\", \"1\")\n    iex> Enviable.fetch_env_integer(\"COLOR\")\n    {:ok, 1}\n\n    iex> Enviable.put_env(\"COLOR\", \"ff\")\n    iex> Enviable.fetch_env_integer(\"COLOR\")\n    :error\n\n    iex> Enviable.put_env(\"COLOR\", \"ff\")\n    iex> Enviable.fetch_env_integer(\"COLOR\", base: 16)\n    {:ok, 255}","ref":"Enviable.html#fetch_env_integer/2-examples"},{"type":"function","title":"Enviable.fetch_env_integer!/2","doc":"Returns the value of an environment variable as a `t:integer/0` value or `nil` if the\nvariable is not set and a `default` is not provided.\n\nThis function accepts the following conversion options:\n\n- `base`: The base (`2..36`) for integer conversion. Defaults to `10` like\n  `String.to_integer/2`.\n- `default`: the default value, which must be either a binary string value or an\n  integer. If provided as a binary, this will be interpreted according to the `base`\n  option provided.\n\nFailure to parse a binary string `default` or the value of the environment variable will\nresult in an exception.","ref":"Enviable.html#fetch_env_integer!/2"},{"type":"function","title":"Examples - Enviable.fetch_env_integer!/2","doc":"iex> Enviable.fetch_env_integer!(\"COLOR\")\n    ** (System.EnvError) could not fetch environment variable \"COLOR\" because it is not set\n\n    iex> Enviable.put_env(\"COLOR\", \"1\")\n    iex> Enviable.fetch_env_integer!(\"COLOR\")\n    1\n\n    iex> Enviable.put_env(\"COLOR\", \"ff\")\n    iex> Enviable.fetch_env_integer!(\"COLOR\")\n    ** (Enviable.ConversionError) could not convert environment variable \"COLOR\" to type integer\n\n    iex> Enviable.put_env(\"COLOR\", \"ff\")\n    iex> Enviable.fetch_env_integer!(\"COLOR\", base: 16)\n    255","ref":"Enviable.html#fetch_env_integer!/2-examples"},{"type":"function","title":"Enviable.get_env/0","doc":"Returns all system environment variables.\n\nThe returned value is a map containing name-value pairs.\nVariable names and their values are strings.","ref":"Enviable.html#get_env/0"},{"type":"function","title":"Enviable.get_env/2","doc":"Returns the value of the given environment variable.\n\nThe returned value of the environment variable\n`varname` is a string. If the environment variable\nis not set, returns the string specified in `default` or\n`nil` if none is specified.","ref":"Enviable.html#get_env/2"},{"type":"function","title":"Examples - Enviable.get_env/2","doc":"iex> Enviable.get_env(\"PORT\")\n    nil\n\n    iex> Enviable.get_env(\"PORT\", \"4001\")\n    \"4001\"\n\n    iex> Enviable.put_env(\"PORT\", \"4000\")\n    iex> Enviable.get_env(\"PORT\")\n    \"4000\"\n    iex> Enviable.get_env(\"PORT\", \"4001\")\n    \"4000\"","ref":"Enviable.html#get_env/2-examples"},{"type":"function","title":"Enviable.get_env_boolean/2","doc":"Returns the value of an environment variable as a `t:boolean/0` value.\n\nBy default, the values `\"1\"` and `\"true\"` are considered `true` values. Any other value,\nincluding unset variable, will be considered `false`.\n\nThis function accepts the following conversion options:\n\n- `truthy`: a list of string values to be compared for truth values. Mutually exclusive\n  with `falsy`.\n- `falsy`: a list of string values to be compared for false values. Mutually exclusive\n  with `truthy`.\n- `downcase`: either `false` (the default), `true`, or the mode parameter for\n  `String.downcase/2` (`:default`, `:ascii`, `:greek`, or `:turkic`).\n- `default`: the default value (which must be `true` or `false`) if the variable is\n  unset. In most cases, when `falsy` is provided, `default: true` should also be\n  provided.","ref":"Enviable.html#get_env_boolean/2"},{"type":"function","title":"Examples - Enviable.get_env_boolean/2","doc":"iex> Enviable.get_env_boolean(\"COLOR\")\n    false\n\n    iex> Enviable.get_env_boolean(\"COLOR\", default: true)\n    true\n\n    iex> Enviable.put_env(\"COLOR\", \"1\")\n    iex> Enviable.get_env_boolean(\"COLOR\")\n    true\n\n    iex> Enviable.put_env(\"COLOR\", \"something\")\n    iex> Enviable.get_env_boolean(\"COLOR\")\n    false\n\n    iex> Enviable.put_env(\"COLOR\", \"oui\")\n    iex> Enviable.get_env_boolean(\"COLOR\", truthy: [\"oui\"])\n    true\n\n    iex> Enviable.put_env(\"COLOR\", \"OUI\")\n    iex> Enviable.get_env_boolean(\"COLOR\", truthy: [\"oui\"])\n    false\n    iex> Enviable.get_env_boolean(\"COLOR\", truthy: [\"oui\"], downcase: true)\n    true\n\n    iex> Enviable.put_env(\"COLOR\", \"NON\")\n    iex> Enviable.get_env_boolean(\"COLOR\", falsy: [\"non\"])\n    true\n    iex> Enviable.get_env_boolean(\"COLOR\", falsy: [\"non\"], downcase: true)\n    false\n\n    iex> Enviable.get_env_boolean(\"COLOR\", default: nil)\n    ** (ArgumentError) cannot execute Enviable.get_env_boolean/2 with non-boolean `default` value\n\n    iex> Enviable.get_env_boolean(\"COLOR\", downcase: nil)\n    ** (ArgumentError) cannot execute Enviable.get_env_boolean/2 with invalid `downcase` value\n\n    iex> Enviable.get_env_boolean(\"COLOR\", truthy: [\"oui\"], falsy: [\"non\"])\n    ** (ArgumentError) cannot execute Enviable.get_env_boolean/2 with both `truthy` and `falsy` options","ref":"Enviable.html#get_env_boolean/2-examples"},{"type":"function","title":"Enviable.get_env_integer/2","doc":"Returns the value of an environment variable as a `t:integer/0` value or `nil` if the\nvariable is not set and a `default` is not provided.\n\nThis function accepts the following conversion options:\n\n- `base`: The base (`2..36`) for integer conversion. Defaults to `10` like\n  `String.to_integer/2`.\n- `default`: the default value, which must be either a binary string value or an\n  integer. If provided as a binary, this will be interpreted according to the `base`\n  option provided.\n\nFailure to parse a binary string `default` or the value of the environment variable will\nresult in an exception.","ref":"Enviable.html#get_env_integer/2"},{"type":"function","title":"Examples - Enviable.get_env_integer/2","doc":"iex> Enviable.get_env_integer(\"COLOR\")\n    nil\n\n    iex> Enviable.get_env_integer(\"COLOR\", default: 255)\n    255\n\n    iex> Enviable.get_env_integer(\"COLOR\", default: \"255\")\n    255\n\n    iex> Enviable.get_env_integer(\"COLOR\", default: 3.5)\n    ** (ArgumentError) cannot execute Enviable.get_env_integer/2 with non-integer `default` value\n\n    iex> Enviable.put_env(\"COLOR\", \"1\")\n    iex> Enviable.get_env_integer(\"COLOR\")\n    1\n\n    iex> Enviable.put_env(\"COLOR\", \"ff\")\n    iex> Enviable.get_env_integer(\"COLOR\")\n    ** (Enviable.ConversionError) could not convert environment variable \"COLOR\" to type integer\n\n    iex> Enviable.put_env(\"COLOR\", \"ff\")\n    iex> Enviable.get_env_integer(\"COLOR\", base: 16)\n    255","ref":"Enviable.html#get_env_integer/2-examples"},{"type":"function","title":"Enviable.put_env/1","doc":"Sets multiple environment variables.\n\nSets a new value for each environment variable corresponding\nto each `{key, value}` pair in `enum`. Keys and non-nil values\nare automatically converted to charlists. `nil` values erase\nthe given keys.\n\nOverall, this is a convenience wrapper around `put_env/2` and\n`delete_env/2` with support for different key and value formats.","ref":"Enviable.html#put_env/1"},{"type":"function","title":"Enviable.put_env/2","doc":"Sets an environment variable value.\n\nSets a new `value` for the environment variable `varname`.","ref":"Enviable.html#put_env/2"},{"type":"function","title":"Enviable.put_env_new/2","doc":"Set an environment variable value only if it is not yet set.","ref":"Enviable.html#put_env_new/2"},{"type":"function","title":"Examples - Enviable.put_env_new/2","doc":"iex> Enviable.put_env_new(\"PORT\", \"3000\")\n    :ok\n    iex> Enviable.get_env(\"PORT\")\n    \"3000\"\n    iex> Enviable.put_env_new(\"PORT\", \"5000\")\n    :ok\n    iex> Enviable.get_env(\"PORT\")\n    \"3000\"","ref":"Enviable.html#put_env_new/2-examples"},{"type":"exception","title":"Enviable.ConversionError","doc":"An exception raised when a provided environment variable cannot be converted to the\nrequested type.","ref":"Enviable.ConversionError.html"},{"type":"extras","title":"Contributing","doc":"# Contributing\n\nI value contributions to Enviable--bug reports, discussions, feature requests,\nand code contributions. New features should be proposed and\n[discussed][discussed].\n\nBefore contributing patches, please read the [Licence](./Licence.md).\n\nEnviable is governed under the [Contributor Covenant Code of Conduct][cccoc].","ref":"contributing.html"},{"type":"extras","title":"Code Guidelines - Contributing","doc":"We have several guidelines to contributing code through pull requests to App\nIdentity reference implementations:\n\n- All code changes require tests. In most cases, this will be added or updated\n  unit tests. We use [ExUnit][ExUnit].\n\n- We use code formatters, static analysis tools, and linting to ensure\n  consistent styles and formatting. There should be no warnings output from\n  compile or test run processes. We use `mix compile --warnings-as-errors`,\n  [Credo][Credo], and `mix format` (with [Styler][Styler])\n\n- Proposed changes should be on a thoughtfully-named topic branch and organized\n  into logical commit chunks as appropriate.\n\n- Use [Conventional Commits][conventional] with our [conventions][conventions].\n\n- Versions must not be updated in pull requests.\n\n- Documentation should be added or updated as appropriate for new or updated\n  functionality.\n\n- New dependencies are discouraged and their addition must be discussed,\n  regardless whether it is a development dependency, optional dependency, or\n  runtime dependency.\n\n- All GitHub Actions checks marked as required must pass before a pull request\n  may be accepted and merged.\n\n[cccoc]: ./Code-of-Conduct.md\n[conventional]: https://www.conventionalcommits.org/en/v1.0.0/\n[conventions]: https://github.com/KineticCafe/app-identity/blob/main/Contributing.md#commit-conventions\n[credo]: https://github.com/rrrene/credo\n[styler]: https://github.com/adobe/styler\n[discussed]: https://github.com/halostatue/enviable/discussions\n[exunit]: https://hexdocs.pm/ex_unit/ExUnit.html","ref":"contributing.html#code-guidelines"},{"type":"extras","title":"Code of Conduct","doc":"# Contributor Covenant Code of Conduct","ref":"Code-of-Conduct.md.html"},{"type":"extras","title":"Our Pledge - Code of Conduct","doc":"We as members, contributors, and leaders pledge to make participation in our\ncommunity a harassment-free experience for everyone, regardless of age, body\nsize, visible or invisible disability, ethnicity, sex characteristics, gender\nidentity and expression, level of experience, education, socio-economic status,\nnationality, personal appearance, race, caste, color, religion, or sexual\nidentity and orientation.\n\nWe pledge to act and interact in ways that contribute to an open, welcoming,\ndiverse, inclusive, and healthy community.","ref":"Code-of-Conduct.md.html#our-pledge"},{"type":"extras","title":"Our Standards - Code of Conduct","doc":"Examples of behavior that contributes to a positive environment for our\ncommunity include:\n\n- Demonstrating empathy and kindness toward other people\n- Being respectful of differing opinions, viewpoints, and experiences\n- Giving and gracefully accepting constructive feedback\n- Accepting responsibility and apologizing to those affected by our mistakes,\n  and learning from the experience\n- Focusing on what is best not just for us as individuals, but for the overall\n  community\n\nExamples of unacceptable behavior include:\n\n- The use of sexualized language or imagery, and sexual attention or advances of\n  any kind\n- Trolling, insulting or derogatory comments, and personal or political attacks\n- Public or private harassment\n- Publishing others' private information, such as a physical or email address,\n  without their explicit permission\n- Other conduct which could reasonably be considered inappropriate in a\n  professional setting","ref":"Code-of-Conduct.md.html#our-standards"},{"type":"extras","title":"Enforcement Responsibilities - Code of Conduct","doc":"Community leaders are responsible for clarifying and enforcing our standards of\nacceptable behavior and will take appropriate and fair corrective action in\nresponse to any behavior that they deem inappropriate, threatening, offensive,\nor harmful.\n\nCommunity leaders have the right and responsibility to remove, edit, or reject\ncomments, commits, code, wiki edits, issues, and other contributions that are\nnot aligned to this Code of Conduct, and will communicate reasons for moderation\ndecisions when appropriate.","ref":"Code-of-Conduct.md.html#enforcement-responsibilities"},{"type":"extras","title":"Scope - Code of Conduct","doc":"This Code of Conduct applies within all community spaces, and also applies when\nan individual is officially representing the community in public spaces.\nExamples of representing our community include using an official email address,\nposting via an official social media account, or acting as an appointed\nrepresentative at an online or offline event.","ref":"Code-of-Conduct.md.html#scope"},{"type":"extras","title":"Enforcement - Code of Conduct","doc":"Instances of abusive, harassing, or otherwise unacceptable behavior may be\nreported to the community leaders responsible for enforcement at [INSERT CONTACT\nMETHOD]. All complaints will be reviewed and investigated promptly and fairly.\n\nAll community leaders are obligated to respect the privacy and security of the\nreporter of any incident.","ref":"Code-of-Conduct.md.html#enforcement"},{"type":"extras","title":"Enforcement Guidelines - Code of Conduct","doc":"Community leaders will follow these Community Impact Guidelines in determining\nthe consequences for any action they deem in violation of this Code of Conduct:","ref":"Code-of-Conduct.md.html#enforcement-guidelines"},{"type":"extras","title":"1. Correction - Code of Conduct","doc":"**Community Impact**: Use of inappropriate language or other behavior deemed\nunprofessional or unwelcome in the community.\n\n**Consequence**: A private, written warning from community leaders, providing\nclarity around the nature of the violation and an explanation of why the\nbehavior was inappropriate. A public apology may be requested.","ref":"Code-of-Conduct.md.html#1-correction"},{"type":"extras","title":"2. Warning - Code of Conduct","doc":"**Community Impact**: A violation through a single incident or series of\nactions.\n\n**Consequence**: A warning with consequences for continued behavior. No\ninteraction with the people involved, including unsolicited interaction with\nthose enforcing the Code of Conduct, for a specified period of time. This\nincludes avoiding interactions in community spaces as well as external channels\nlike social media. Violating these terms may lead to a temporary or permanent\nban.","ref":"Code-of-Conduct.md.html#2-warning"},{"type":"extras","title":"3. Temporary Ban - Code of Conduct","doc":"**Community Impact**: A serious violation of community standards, including\nsustained inappropriate behavior.\n\n**Consequence**: A temporary ban from any sort of interaction or public\ncommunication with the community for a specified period of time. No public or\nprivate interaction with the people involved, including unsolicited interaction\nwith those enforcing the Code of Conduct, is allowed during this period.\nViolating these terms may lead to a permanent ban.","ref":"Code-of-Conduct.md.html#3-temporary-ban"},{"type":"extras","title":"4. Permanent Ban - Code of Conduct","doc":"**Community Impact**: Demonstrating a pattern of violation of community\nstandards, including sustained inappropriate behavior, harassment of an\nindividual, or aggression toward or disparagement of classes of individuals.\n\n**Consequence**: A permanent ban from any sort of public interaction within the\ncommunity.","ref":"Code-of-Conduct.md.html#4-permanent-ban"},{"type":"extras","title":"Attribution - Code of Conduct","doc":"This Code of Conduct is adapted from the [Contributor Covenant][homepage],\nversion 2.1, available at\n .\n\nCommunity Impact Guidelines were inspired by\n[Mozilla's code of conduct enforcement ladder][Mozilla CoC].\n\nFor answers to common questions about this code of conduct, see the FAQ at\n . Translations are available at\n .\n\n[homepage]: https://www.contributor-covenant.org\n[Mozilla CoC]: https://github.com/mozilla/diversity","ref":"Code-of-Conduct.md.html#attribution"},{"type":"extras","title":"CHANGELOG","doc":"# App Identity for Elixir Changelog","ref":"Changelog.md.html"},{"type":"extras","title":"1.0.0 / 2024-12-10 - CHANGELOG","doc":"- Initial release.","ref":"Changelog.md.html#1-0-0-2024-12-10"},{"type":"extras","title":"Licence","doc":"# Licence\n\nEnviable is copyright © 2024 Austin Ziegler and is licensed under\n[Apache License, version 2.0](licences/APACHE-2.0.txt). Portions of Enviable are\nadapted from the `System` module in [Elixir][elixir].","ref":"Licence.md.html"},{"type":"extras","title":"Developer Certificate of Origin - Licence","doc":"All contributors **must** certify they are able and willing to provide their\ncontributions under the terms of this project's licences with the certification\nof the [Developer Certificate of Origin (Version 1.1)](licences/dco.txt).\n\nSuch certification is provided by ensuring that a `Signed-off-by`\n[commit trailer][trailer] is present on every commit:\n\n    Signed-off-by: FirstName LastName  \n\nThe `Signed-off-by` trailer can be automatically added by git with the `-s` or\n`--signoff` option on `git commit`:\n\n```sh\ngit commit --signoff\n```\n\n[trailer]: https://git-scm.com/docs/git-interpret-trailers\n[elixir]: https://github.com/elixir-lang/elixir","ref":"Licence.md.html#developer-certificate-of-origin"},{"type":"extras","title":"Apache License, version 2.0","doc":"Apache License\nVersion 2.0, January 2004\nhttp://www.apache.org/licenses/\n\nTERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n1. Definitions.\n\n\"License\" shall mean the terms and conditions for use, reproduction, and\ndistribution as defined by Sections 1 through 9 of this document.\n\n\"Licensor\" shall mean the copyright owner or entity authorized by the copyright\nowner that is granting the License.\n\n\"Legal Entity\" shall mean the union of the acting entity and all other entities\nthat control, are controlled by, or are under common control with that entity.\nFor the purposes of this definition, \"control\" means (i) the power, direct or\nindirect, to cause the direction or management of such entity, whether by\ncontract or otherwise, or (ii) ownership of fifty percent (50%) or more of the\noutstanding shares, or (iii) beneficial ownership of such entity.\n\n\"You\" (or \"Your\") shall mean an individual or Legal Entity exercising\npermissions granted by this License.\n\n\"Source\" form shall mean the preferred form for making modifications, including\nbut not limited to software source code, documentation source, and configuration\nfiles.\n\n\"Object\" form shall mean any form resulting from mechanical transformation or\ntranslation of a Source form, including but not limited to compiled object code,\ngenerated documentation, and conversions to other media types.\n\n\"Work\" shall mean the work of authorship, whether in Source or Object form, made\navailable under the License, as indicated by a copyright notice that is included\nin or attached to the work (an example is provided in the Appendix below).\n\n\"Derivative Works\" shall mean any work, whether in Source or Object form, that\nis based on (or derived from) the Work and for which the editorial revisions,\nannotations, elaborations, or other modifications represent, as a whole, an\noriginal work of authorship. For the purposes of this License, Derivative Works\nshall not include works that remain separable from, or merely link (or bind by\nname) to the interfaces of, the Work and Derivative Works thereof.\n\n\"Contribution\" shall mean any work of authorship, including the original version\nof the Work and any modifications or additions to that Work or Derivative Works\nthereof, that is intentionally submitted to Licensor for inclusion in the Work\nby the copyright owner or by an individual or Legal Entity authorized to submit\non behalf of the copyright owner. For the purposes of this definition,\n\"submitted\" means any form of electronic, verbal, or written communication sent\nto the Licensor or its representatives, including but not limited to\ncommunication on electronic mailing lists, source code control systems, and\nissue tracking systems that are managed by, or on behalf of, the Licensor for\nthe purpose of discussing and improving the Work, but excluding communication\nthat is conspicuously marked or otherwise designated in writing by the copyright\nowner as \"Not a Contribution.\"\n\n\"Contributor\" shall mean Licensor and any individual or Legal Entity on behalf\nof whom a Contribution has been received by Licensor and subsequently\nincorporated within the Work.\n\n2. Grant of Copyright License.\n\nSubject to the terms and conditions of this License, each Contributor hereby\ngrants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free,\nirrevocable copyright license to reproduce, prepare Derivative Works of,\npublicly display, publicly perform, sublicense, and distribute the Work and such\nDerivative Works in Source or Object form.\n\n3. Grant of Patent License.\n\nSubject to the terms and conditions of this License, each Contributor hereby\ngrants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free,\nirrevocable (except as stated in this section) patent license to make, have\nmade, use, offer to sell, sell, import, and otherwise transfer the Work, where\nsuch license applies only to those patent claims licensable by such Contributor\nthat are necessarily infringed by their Contribution(s) alone or by combination\nof their Contribution(s) with the Work to which such Contribution(s) was\nsubmitted. If You institute patent litigation against any entity (including\na cross-claim or counterclaim in a lawsuit) alleging that the Work or\na Contribution incorporated within the Work constitutes direct or contributory\npatent infringement, then any patent licenses granted to You under this License\nfor that Work shall terminate as of the date such litigation is filed.\n\n4. Redistribution.\n\nYou may reproduce and distribute copies of the Work or Derivative Works thereof\nin any medium, with or without modifications, and in Source or Object form,\nprovided that You meet the following conditions:\n\n- You must give any other recipients of the Work or Derivative Works a copy of\n  this License; and\n- You must cause any modified files to carry prominent notices stating that You\n  changed the files; and\n- You must retain, in the Source form of any Derivative Works that You\n  distribute, all copyright, patent, trademark, and attribution notices from the\n  Source form of the Work, excluding those notices that do not pertain to any\n  part of the Derivative Works; and\n- If the Work includes a \"NOTICE\" text file as part of its distribution, then\n  any Derivative Works that You distribute must include a readable copy of the\n  attribution notices contained within such NOTICE file, excluding those notices\n  that do not pertain to any part of the Derivative Works, in at least one of\n  the following places: within a NOTICE text file distributed as part of the\n  Derivative Works; within the Source form or documentation, if provided along\n  with the Derivative Works; or, within a display generated by the Derivative\n  Works, if and wherever such third-party notices normally appear. The contents\n  of the NOTICE file are for informational purposes only and do not modify the\n  License. You may add Your own attribution notices within Derivative Works that\n  You distribute, alongside or as an addendum to the NOTICE text from the Work,\n  provided that such additional attribution notices cannot be construed as\n  modifying the License.\n\nYou may add Your own copyright statement to Your modifications and may provide\nadditional or different license terms and conditions for use, reproduction, or\ndistribution of Your modifications, or for any such Derivative Works as a whole,\nprovided Your use, reproduction, and distribution of the Work otherwise complies\nwith the conditions stated in this License.\n\n5. Submission of Contributions.\n\nUnless You explicitly state otherwise, any Contribution intentionally submitted\nfor inclusion in the Work by You to the Licensor shall be under the terms and\nconditions of this License, without any additional terms or conditions.\nNotwithstanding the above, nothing herein shall supersede or modify the terms of\nany separate license agreement you may have executed with Licensor regarding\nsuch Contributions.\n\n6. Trademarks.\n\nThis License does not grant permission to use the trade names, trademarks,\nservice marks, or product names of the Licensor, except as required for\nreasonable and customary use in describing the origin of the Work and\nreproducing the content of the NOTICE file.\n\n7. Disclaimer of Warranty.\n\nUnless required by applicable law or agreed to in writing, Licensor provides the\nWork (and each Contributor provides its Contributions) on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied,\nincluding, without limitation, any warranties or conditions of TITLE,\nNON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. You are\nsolely responsible for determining the appropriateness of using or\nredistributing the Work and assume any risks associated with Your exercise of\npermissions under this License.\n\n8. Limitation of Liability.\n\nIn no event and under no legal theory, whether in tort (including negligence),\ncontract, or otherwise, unless required by applicable law (such as deliberate\nand grossly negligent acts) or agreed to in writing, shall any Contributor be\nliable to You for damages, including any direct, indirect, special, incidental,\nor consequential damages of any character arising as a result of this License or\nout of the use or inability to use the Work (including but not limited to\ndamages for loss of goodwill, work stoppage, computer failure or malfunction, or\nany and all other commercial damages or losses), even if such Contributor has\nbeen advised of the possibility of such damages.\n\n9. Accepting Warranty or Additional Liability.\n\nWhile redistributing the Work or Derivative Works thereof, You may choose to\noffer, and charge a fee for, acceptance of support, warranty, indemnity, or\nother liability obligations and/or rights consistent with this License. However,\nin accepting such obligations, You may act only on Your own behalf and on Your\nsole responsibility, not on behalf of any other Contributor, and only if You\nagree to indemnify, defend, and hold each Contributor harmless for any liability\nincurred by, or claims asserted against, such Contributor by reason of your\naccepting any such warranty or additional liability.\n\nEND OF TERMS AND CONDITIONS","ref":"APACHE-2.0.txt.html"},{"type":"extras","title":"Developer Certificate of Origin","doc":"Developer Certificate of Origin\nVersion 1.1\n\nCopyright (C) 2004, 2006 The Linux Foundation and its contributors.\n\nEveryone is permitted to copy and distribute verbatim copies of this\nlicense document, but changing it is not allowed.\n\n\nDeveloper's Certificate of Origin 1.1\n\nBy making a contribution to this project, I certify that:\n\n(a) The contribution was created in whole or in part by me and I\n    have the right to submit it under the open source license\n    indicated in the file; or\n\n(b) The contribution is based upon previous work that, to the best\n    of my knowledge, is covered under an appropriate open source\n    license and I have the right under that license to submit that\n    work with modifications, whether created in whole or in part\n    by me, under the same open source license (unless I am\n    permitted to submit under a different license), as indicated\n    in the file; or\n\n(c) The contribution was provided directly to me by some other\n    person who certified (a), (b) or (c) and I have not modified\n    it.\n\n(d) I understand and agree that this project and the contribution\n    are public and that a record of the contribution (including all\n    personal information I submit with it, including my sign-off) is\n    maintained indefinitely and may be redistributed consistent with\n    this project or the open source license(s) involved.","ref":"dco.txt.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}